@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11517 2019-05-03 12:53:40Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Andy $ (last)
+# $Date: 2019-05-03 21:53:40 +0900 (週五, 03 五月 2019) $
+# $Revision: 11517 $
 #
 # Contributors:
 #  Bear (original author)
@@ -50,6 +50,7 @@ def attachSettings(settingsLocals, backends, preferred, config):
             "queue": "mail",
         },
     })
+    
 
 from django.core.mail.backends.base import BaseEmailBackend
 from django.core.mail.backends.smtp import EmailBackend as SMTPBackend
@@ -96,7 +97,7 @@ class EmailBackend(BaseEmailBackend):
         if not email_messages:
             return
 
-        ex = None
+        _ex = None
         numSent = 0
         try:
             # We must reset connection to None to make it be able to pickle.
@@ -121,6 +122,7 @@ class EmailBackend(BaseEmailBackend):
                 numSent = sendResult
 
         except Exception as ex:
+            _ex = ex
             logger.debug('send task failed: %s:%s' % (type(ex), str(ex)))
             logger.debug(''.join(traceback.format_exception(*sys.exc_info())))
             
@@ -150,8 +152,8 @@ class EmailBackend(BaseEmailBackend):
                     logger.info('fallback to SMTP backend: %d sent' % 
                                 fallbackNumSent)
                 except Exception as retryEx:
-                    if not self.fail_silently and ex:
-                        raise RetryAndSendException(retryEx, ex)
+                    if not self.fail_silently and _ex:
+                        raise RetryAndSendException(retryEx, _ex)
                     else:
                         raise RetryException(retryEx)
 
