@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_project.py 11485 2019-04-24 03:19:25Z Lavender $
+# $Id: start_project.py 11499 2019-04-27 18:19:55Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-24 11:19:25 +0800 (週三, 24 四月 2019) $
-# $Revision: 11485 $
+# $Date: 2019-04-28 03:19:55 +0900 (週日, 28 四月 2019) $
+# $Revision: 11499 $
 
 import os
 import sys
 import six
+import shutil
 import datetime
 
 from django.core.management.base import BaseCommand, CommandError
@@ -27,26 +28,86 @@ from django.template import Context
 from Iuno.Version import IUNO_VERSION
 from Iuppiter.Encoding import utf8
 
+# Mercurius
+IUNO_BASE_PATH = "\\Mercurius\\trunk\\Iuno\\Iuno"
+
+# Pandora
+SCAFFOLD_TEMP_PATH = "\\Pandora\\trunk\\Containers\\Apps\\Scaffold\\_Scaffold"
+SCAFFOLD_PATH = "\\Pandora\\trunk\\Containers\\Apps\\Scaffold\\Scaffold"
+
+# http://landcareweb.com/questions/6325/python-yi-dong-bing-fu-gai-wen-jian-he-wen-jian-jia
+def forceCopyFile (sfile, dfile):
+    if os.path.isfile(sfile):
+        shutil.copy2(sfile, dfile)
+        
+def forceMergeFlatDir(srcDir, dstDir):
+    if not os.path.exists(dstDir):
+        os.makedirs(dstDir)
+    for item in os.listdir(srcDir):
+        srcFile = os.path.join(srcDir, item)
+        dstFile = os.path.join(dstDir, item)
+        forceCopyFile(srcFile, dstFile)
+        
+def isAFlatDir(sDir):
+    for item in os.listdir(sDir):
+        sItem = os.path.join(sDir, item)
+        if os.path.isdir(sItem):
+            return False
+    return True
+
+def copyTree(src, dst):
+    for item in os.listdir(src):
+        s = os.path.join(src, item)
+        d = os.path.join(dst, item)
+        if os.path.isfile(s):
+            if not os.path.exists(dst):
+                os.makedirs(dst)
+            forceCopyFile(s,d)
+        if os.path.isdir(s):
+            isRecursive = not isAFlatDir(s)
+            if isRecursive:
+                copyTree(s, d)
+            else:
+                forceMergeFlatDir(s, d)
+
 
 class Command(BaseCommand):
     help = 'Build django project with our setting and files.'
 
     def add_arguments(self, parser):
-        parser.add_argument('name', type=str, help="Project name")
+        parser.add_argument('name', type=str, nargs='?', help="Project name")
         parser.add_argument('path', type=str, nargs='?', help="Project path")
+        parser.add_argument(
+            '--pandora', 
+            action='store_true',
+            help="Update or create Pandora Scaffold project.")
 
     def handle(self, *args, **options):
         path = options['path']
         name = options['name']
+        pandora = options['pandora']
+        
+        if pandora:
+            name = "Scaffold"
+            path = os.path.abspath(os.path.dirname(__name__))
+            pandoraPath = path.replace(IUNO_BASE_PATH, SCAFFOLD_PATH)
+            path = path.replace(IUNO_BASE_PATH, SCAFFOLD_TEMP_PATH)
+            tempPath = path
+            if not os.path.exists(path):
+                os.mkdir(path)
+        
+        if not name:
+            print("Please type project name.")
+            return
 
         if not path:
-            path = os.path.join(os.getcwd(), options['name'])
+            path = os.path.join(os.getcwd(), name)
         else:
-            path = os.path.join(path, options['name'])
+            path = os.path.join(path, name)
 
         # FIXME: 判斷 Manage.py
         if os.path.abspath(path) == os.path.abspath(
-                os.path.join(os.getcwd(), options['name'])):
+                os.path.join(os.getcwd(), name)):
             os.system(
                 "%s manage.py startproject %s" % (
                     sys.executable, name))
@@ -113,6 +174,7 @@ class Command(BaseCommand):
         with open(os.path.join(commandPath, "__init__.py"), 'w') as f:
             pass
             
+        # 之所以 template 用 .txt 是因為 setup 的時候會嘗試去 import
         renderFile('scaffold/Deploy.txt', commandPath, 'deploy.py')
 
         # Settings.txt ----------------------------------------------------------
@@ -131,6 +193,7 @@ class Command(BaseCommand):
         context = {
             "name": name.lower(),
             "version": IUNO_VERSION,
+            "pandora": pandora,
         }
         temp = get_template('scaffold/DebugTemplate.txt')
         debug = temp.render(context)
@@ -206,6 +269,12 @@ class Command(BaseCommand):
 
         with open(urlPath, 'w') as url:
             url.write(content)
+            
+        # pandora
+        if pandora:
+            copyTree(path, pandoraPath)
+            shutil.rmtree(tempPath)
+            
 
 
 
