@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11751 2019-10-16 02:58:57Z Lavender $
+# $Id: forms.py 11753 2019-10-20 17:58:13Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-16 11:58:57 +0900 (週三, 16 十月 2019) $
-# $Revision: 11751 $
+# $Date: 2019-10-21 02:58:13 +0900 (週一, 21 十月 2019) $
+# $Revision: 11753 $
 
 import os
 import hashlib
@@ -45,17 +45,8 @@ Product = get_model('catalogue', 'Product')
 _ProductForm = get_class('dashboard.catalogue.forms', 'ProductForm')
 
 class ProductForm(_ProductForm):
-    class Meta:
-        model = Product
+    class Meta(_ProductForm.Meta):
         
-        if not VERSION >= (2, 0, 0):
-            fields = [
-                'title', 'upc', 'description', 'is_discountable', 'structure']
-        else:
-            fields = [
-                'title', 'upc', 'description', 
-                'is_discountable', 'structure', 'is_public']
-            
         if hasattr(settings, 'IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR'):
             if settings.IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR:
                 widgets = {
@@ -87,7 +78,7 @@ class ProductSearchForm(_ProductSearchForm):
     )
     category = forms.ModelChoiceField(
         queryset=Category.objects.all(), 
-        label=_("Variants"), required=False
+        label=_("Categories"), required=False
     )
     dateFrom = forms.DateField(
         required=False, label=_("Date from"), widget=DatePickerInput)
