@@ -89,17 +89,15 @@ class AllPayTrade(models.Model):
 class SpgatewayTrade(models.Model):
     merchantId = models.CharField(max_length=30)
     merchantTradeNo = models.CharField(max_length=30)
-    tradeNo = models.CharField(max_length=30)
-    
+    tradeNo = models.CharField(max_length=30)   
     paymentDate = models.DateTimeField()
-    
-    paymentType = models.CharField(max_length=30)
-    paymentMethod = models.CharField(max_length=30)
+    paymentType = models.CharField(max_length=30) 
     tradeAmt = models.IntegerField()
-         
-    rtnCode = models.CharField(max_length=30)
     rtnMsg = models.CharField(max_length=30)
-
+    
+    paymentMethod = models.CharField(max_length=30, null=True)
+    rtnCode = models.CharField(max_length=30, null=True)
+    
 class CathaybkCreditTrade(models.Model):
     merchantId = models.CharField(max_length=30) # STOREID
     merchantTradeNo = models.CharField(max_length=30) # ORDERNUMBER
